.. _changelog_toplevel:

Changes and Migration
=====================

SQLAlchemy changelogs and migration guides are now integrated
within the main documentation.

Current Migration Guide
-----------------------

.. toctree::
   :titlesonly:

   migration_12

Change logs
-----------

.. toctree::
   :titlesonly:

   changelog_12
   changelog_11
   changelog_10
   changelog_09
   changelog_08
   changelog_07
   changelog_06
   changelog_05
   changelog_04
   changelog_03
   changelog_02
   changelog_01


Older Migration Guides
----------------------

.. toctree::
   :titlesonly:

   migration_11
   migration_10
   migration_09
   migration_08
   migration_07
   migration_06
   migration_05
   migration_04
